[bknr-cvs] edi changed trunk/thirdparty/hunchentoot/

BKNR Commits bknr at bknr.net
Mon Feb 9 11:52:41 UTC 2009


Revision: 4203
Author: edi
URL: http://bknr.net/trac/changeset/4203

Some LW fixes

U   trunk/thirdparty/hunchentoot/connection-manager.lisp
U   trunk/thirdparty/hunchentoot/server.lisp

Modified: trunk/thirdparty/hunchentoot/connection-manager.lisp
===================================================================
--- trunk/thirdparty/hunchentoot/server.lisp	2009-02-09 11:47:33 UTC (rev 4202)
+++ trunk/thirdparty/hunchentoot/server.lisp	2009-02-09 11:52:41 UTC (rev 4203)
@@ -83,7 +83,7 @@
    #+:lispworks
    (acceptor :accessor server-acceptor
              :documentation "The Lisp process which accepts incoming
-             requests.")
+requests.")
    #-:lispworks
    (listen-socket :accessor server-listen-socket
                   :documentation "The listen socket for incoming
@@ -376,7 +376,7 @@
                                 :wait t)
       (when startup-condition
         (error startup-condition))
-      (process-stop listener-process)
+      (mp:process-stop listener-process)
       (setf (server-acceptor server) listener-process))
     #-:lispworks
     (setf (server-listen-socket server)
@@ -392,7 +392,7 @@
 using HANDLE-INCOMING-CONNECTION.")
   (:method ((server server))
     #+:lispworks
-    (process-unstop (server-acceptor server))
+    (mp:process-unstop (server-acceptor server))
     #-:lispworks
     (usocket:with-server-socket (listener (server-listen-socket server))
       (do ((new-connection-p (usocket:wait-for-input listener :timeout +new-connection-wait-time+)
@@ -407,9 +407,8 @@
                                 (server-write-timeout server))
                   (handle-incoming-connection (server-connection-manager server)
                                               client-connection)))
-            (usocket:connection-aborted-error ()
-              ;; ignore condition
-              )))))))
+            ;; ignore condition
+            (usocket:connection-aborted-error ())))))))
 
 (defgeneric initialize-connection-stream (server stream) 
  (:documentation "Wraps the given STREAM with all the additional





More information about the Bknr-cvs mailing list
--- trunk/thirdparty/hunchentoot/connection-manager.lisp	2009-02-09 11:47:33 UTC (rev 4202)
+++ trunk/thirdparty/hunchentoot/connection-manager.lisp	2009-02-09 11:52:41 UTC (rev 4203)
@@ -71,10 +71,10 @@
 with the connection manager, if any.")
   (:method (manager)
     #+:lispworks
-    (when-let (listener (server-listener (server manager)))
-      ;; kill the main listener process, see LW documentation for
+    (when-let (acceptor (server-acceptor (server manager)))
+      ;; kill the main acceptor process, see LW documentation for
       ;; COMM:START-UP-SERVER
-      (mp:process-kill listener))))
+      (mp:process-kill acceptor))))
 
 (defclass single-threaded-connection-manager (connection-manager)
   ()

Modified: trunk/thirdparty/hunchentoot/server.lisp
===================================================================